@@ -8,12 +8,16 @@ import httpx
 
 from .account import Account
 from .account_address import AccountAddress
-from .authenticator import (Authenticator, Ed25519Authenticator,
-                            MultiAgentAuthenticator)
+from .authenticator import Authenticator, Ed25519Authenticator, MultiAgentAuthenticator
 from .bcs import Serializer
-from .transactions import (MultiAgentRawTransaction, RawTransaction,
-                           ScriptFunction, SignedTransaction,
-                           TransactionArgument, TransactionPayload)
+from .transactions import (
+    MultiAgentRawTransaction,
+    RawTransaction,
+    ScriptFunction,
+    SignedTransaction,
+    TransactionArgument,
+    TransactionPayload,
+)
 from .type_tag import StructTag, TypeTag
 
 U64_MAX = 18446744073709551615
@@ -121,11 +125,11 @@ class RestClient:
         }
 
         res = self.client.post(
-            f"{self.base_url}/transactions/signing_message", json=txn_request
+            f"{self.base_url}/transactions/encode_submission", json=txn_request
         )
         assert res.status_code == 200, res.text
 
-        to_sign = bytes.fromhex(res.json()["message"][2:])
+        to_sign = bytes.fromhex(res.json()[2:])
         signature = sender.sign(to_sign)
         txn_request["signature"] = {
             "type": "ed25519_signature",
@@ -141,7 +145,7 @@ class RestClient:
         return response.json()["hash"]
 
     def transaction_pending(self, txn_hash: str) -> bool:
-        response = self.client.get(f"{self.base_url}/transactions/{txn_hash}")
+        response = self.client.get(f"{self.base_url}/transactions/by_hash/{txn_hash}")
         if response.status_code == 404:
             return True
         assert response.status_code == 200, f"{response.text} - {txn_hash}"
@@ -155,7 +159,7 @@ class RestClient:
             assert count < 10, f"transaction {txn_hash} timed out"
             time.sleep(1)
             count += 1
-        response = self.client.get(f"{self.base_url}/transactions/{txn_hash}")
+        response = self.client.get(f"{self.base_url}/transactions/by_hash/{txn_hash}")
         assert (
             "success" in response.json() and response.json()["success"]
         ), f"{response.text} - {txn_hash}"
@@ -405,8 +409,8 @@ class RestClient:
             TransactionArgument(creators_address, Serializer.struct),
             TransactionArgument(collection_name, Serializer.str),
             TransactionArgument(token_name, Serializer.str),
-            TransactionArgument(amount, Serializer.u64),
             TransactionArgument(property_version, Serializer.u64),
+            TransactionArgument(amount, Serializer.u64),
         ]
 
         payload = ScriptFunction.natural(
